@@ -954,47 +954,107 @@ def _cast(typ, value):
 # Data representation classes.
 #
 
+from .enum_import01 import Type01_1
+from .enum_import02 import Type02_1
 
-class EnumType02_1(str, Enum):
-    FLOAT='float'
-    INT='int'
-    NAME='Name'
-    TOKEN='token'
+class EnumType00_1(str, Enum):
+    """Simple type enumeration with restrictions"""
+    FLOAT='float' # Enumeration value: 'float'
+    INT='int' # Enumeration value: 'int'
+    NAME='Name' # Enumeration value: 'Name'
+    TOKEN='token' # Enumeration value: 'token'
 
 
-class Type02_1(GeneratedsSuper):
+class Type00_1(GeneratedsSuper):
     __hash__ = GeneratedsSuper.__hash__
     member_data_items_ = {
-        'userdescription': MemberSpec_('userdescription', 'xs:string', 0, 0, {'name': 'userdescription', 'type': 'xs:string'}, None),
+        'inner01': MemberSpec_('inner01', 'Type01_1', 0, 0, {'name': 'inner01', 'type': 'Type01_1'}, None),
+        'inner02': MemberSpec_('inner02', 'Type02_1', 0, 0, {'name': 'inner02', 'type': 'Type02_1'}, None),
     }
     subclass = None
     superclass = None
-    def __init__(self, userdescription=None, gds_collector_=None, **kwargs_):
+    def __init__(self, inner01=None, inner02=None, gds_collector_=None, **kwargs_):
         self.gds_collector_ = gds_collector_
-        self.userdescription = userdescription
+        self.inner01 = inner01
+        self.inner02 = inner02
     def factory(*args_, **kwargs_):
         if CurrentSubclassModule_ is not None:
             subclass = getSubclassFromModule_(
-                CurrentSubclassModule_, Type02_1)
+                CurrentSubclassModule_, Type00_1)
             if subclass is not None:
                 return subclass(*args_, **kwargs_)
-        if Type02_1.subclass:
-            return Type02_1.subclass(*args_, **kwargs_)
+        if Type00_1.subclass:
+            return Type00_1.subclass(*args_, **kwargs_)
         else:
-            return Type02_1(*args_, **kwargs_)
+            return Type00_1(*args_, **kwargs_)
     factory = staticmethod(factory)
-    def get_userdescription(self):
-        return self.userdescription
-    def set_userdescription(self, userdescription):
-        self.userdescription = userdescription
+    def get_inner01(self):
+        return self.inner01
+    def set_inner01(self, inner01):
+        self.inner01 = inner01
+    def get_inner02(self):
+        return self.inner02
+    def set_inner02(self, inner02):
+        self.inner02 = inner02
     def hasContent_(self):
         if (
-            self.userdescription is not None
+            self.inner01 is not None or
+            self.inner02 is not None
         ):
             return True
         else:
             return False
-# end class Type02_1
+# end class Type00_1
+
+
+class Type00_2(GeneratedsSuper):
+    __hash__ = GeneratedsSuper.__hash__
+    member_data_items_ = {
+        'attr1': MemberSpec_('attr1', 'enum_import01:IntType01_1', 0, 1, {'use': 'optional'}),
+    }
+    subclass = None
+    superclass = None
+    def __init__(self, attr1='33', gds_collector_=None, **kwargs_):
+        self.gds_collector_ = gds_collector_
+        self.attr1 = _cast(int, attr1)
+    def factory(*args_, **kwargs_):
+        if CurrentSubclassModule_ is not None:
+            subclass = getSubclassFromModule_(
+                CurrentSubclassModule_, Type00_2)
+            if subclass is not None:
+                return subclass(*args_, **kwargs_)
+        if Type00_2.subclass:
+            return Type00_2.subclass(*args_, **kwargs_)
+        else:
+            return Type00_2(*args_, **kwargs_)
+    factory = staticmethod(factory)
+    def get_attr1(self):
+        return self.attr1
+    def set_attr1(self, attr1):
+        self.attr1 = attr1
+    def validate_IntType01_1(self, value):
+        # Validate type enum_import01:IntType01_1, a restriction on xs:int.
+        if value is not None and Validate_simpletypes_ and self.gds_collector_ is not None:
+            if not isinstance(value, int):
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s is not of the correct base simple type (int)' % {"value": value, "lineno": lineno, })
+                return False
+            if value < 0:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd minInclusive restriction on IntType01_1' % {"value": value, "lineno": lineno} )
+                result = False
+            if value > 127:
+                lineno = self.gds_get_node_lineno_()
+                self.gds_collector_.add_message('Value "%(value)s"%(lineno)s does not match xsd maxInclusive restriction on IntType01_1' % {"value": value, "lineno": lineno} )
+                result = False
+    def hasContent_(self):
+        if (
+
+        ):
+            return True
+        else:
+            return False
+# end class Type00_2
 
 
 GDSClassesMapping = {
@@ -1005,5 +1065,8 @@ RenameMappings_ = {
 
 }
 __all__ = [
+    "Type00_1",
+    "Type00_2",
+    "Type01_1",
     "Type02_1"
 ]
